==> scanbot_sdk-1.1.0.tar.gz: android/src/main/kotlin/io/scanbot/sdk/flutter/ObjectMapper.kt <==
/*
    Scanbot SDK Flutter Plugin

    Copyright (c) 2019 doo GmbH. All rights reserved.
 */
package io.scanbot.sdk.flutter

import androidx.core.net.toUri
import com.google.gson.Gson
import com.google.gson.JsonObject
import io.scanbot.sdk.flutter.utils.JsonUtils
import io.scanbot.sdk.persistence.Page
import net.doo.snap.process.OcrResult
import org.json.JSONObject
import java.io.File

fun ocrResultToJson(ocrResult: OcrResult, newFile: File?): JSONObject {
    val ocrResultJson = JsonUtils.resultToJson(ocrResult)

    ocrResult.sandwichedPdfDocumentFile?.toUri()?.toString()?.let {
        ocrResultJson.put(
                "pdfFileUri",
                it
        )
    }

    newFile?.toUri()?.toString()?.let {
        ocrResultJson.put(
                "pdfFileUri",
                it
        )
    }

    ocrResult.recognizedText?.let {
        ocrResultJson.put("plainText", it)
    }

    return ocrResultJson
}

typealias PageJson = HashMap<String, Any>
typealias OcrOptionsJson = HashMap<String, Any>
typealias TiffOptionsJson = HashMap<String, Any>
typealias PdfOptionsJson = HashMap<String, Any>
typealias PagesJson = List<HashMap<String, Any>>
typealias LanguagesJson = ArrayList<String>
typealias SizeJson = HashMap<String, Any>
typealias DocumentScannerConfigurationJson = HashMap<String, Any>
typealias MRZScannerConfigurationJson = HashMap<String, Any>
typealias CroppingConfigurationJson = HashMap<String, Any>
typealias BarcodeScannerConfigurationJson = HashMap<String, Any>
typealias EhicScannerConfigurationJson = HashMap<String, Any>

fun PageJson.toPage(gson: Gson): Page {
    return gson.fromJson(JSONObject(this).toString(), Page::class.java)
}

fun Page.toJson(gson: Gson): JsonObject {
    val size = documentImageSizeLimit
    val jsonObject = gson.toJsonTree(this) as JsonObject
    if (size.width == Integer.MAX_VALUE && size.height == Integer.MAX_VALUE) {
        jsonObject.remove("documentImageSizeLimit")
    }
    return jsonObject
}

fun SizeJson.toSize(gson: Gson): Page.Size {
    return gson.fromJson(JSONObject(this).toString(), Page.Size::class.java)
}

==> scanbot_sdk-2.0.1.tar.gz: android/src/main/kotlin/io/scanbot/sdk/flutter/ObjectMapper.kt <==
/*
    Scanbot SDK Flutter Plugin

    Copyright (c) 2019 doo GmbH. All rights reserved.
 */
package io.scanbot.sdk.flutter

import androidx.core.net.toUri
import com.google.gson.Gson
import com.google.gson.JsonObject
import io.scanbot.sdk.flutter.utils.JsonUtils
import io.scanbot.sdk.ocr.process.OcrResult
import io.scanbot.sdk.persistence.Page
import org.json.JSONObject
import java.io.File

fun ocrResultToJson(ocrResult: OcrResult, newFile: File?): JSONObject {
    val ocrResultJson = JsonUtils.resultToJson(ocrResult)

    ocrResult.sandwichedPdfDocumentFile?.toUri()?.toString()?.let {
        ocrResultJson.put(
                "pdfFileUri",
                it
        )
    }

    newFile?.toUri()?.toString()?.let {
        ocrResultJson.put(
                "pdfFileUri",
                it
        )
    }

    ocrResult.recognizedText?.let {
        ocrResultJson.put("plainText", it)
    }

    return ocrResultJson
}

typealias PageJson = HashMap<String, Any>
typealias OcrOptionsJson = HashMap<String, Any>
typealias TiffOptionsJson = HashMap<String, Any>
typealias PdfOptionsJson = HashMap<String, Any>
typealias PagesJson = List<HashMap<String, Any>>
typealias LanguagesJson = ArrayList<String>
typealias SizeJson = HashMap<String, Any>
typealias DocumentScannerConfigurationJson = HashMap<String, Any>
typealias MRZScannerConfigurationJson = HashMap<String, Any>
typealias CroppingConfigurationJson = HashMap<String, Any>
typealias BarcodeScannerConfigurationJson = HashMap<String, Any>
typealias EhicScannerConfigurationJson = HashMap<String, Any>

fun PageJson.toPage(gson: Gson): Page {
    return gson.fromJson(JSONObject(this).toString(), Page::class.java)
}

fun Page.toJson(gson: Gson): JsonObject {
    val size = documentImageSizeLimit
    val jsonObject = gson.toJsonTree(this) as JsonObject
    if (size.width == Integer.MAX_VALUE && size.height == Integer.MAX_VALUE) {
        jsonObject.remove("documentImageSizeLimit")
    }
    return jsonObject
}

fun SizeJson.toSize(gson: Gson): Page.Size {
    return gson.fromJson(JSONObject(this).toString(), Page.Size::class.java)
}
